@@ -9,6 +9,8 @@
 
 ## create an agreement score matrix from a vote matrix
 ## subjects initially on rows and items on cols of X
+## note: treats missing votes as category for agreement / might be
+##       more principled to treat them in another fashion
 "agree.mat" <- function(X){
   X <- t(X) # put subjects on columns
   n <- ncol(X)
@@ -216,6 +218,7 @@
 ## takes a subject by subject agreement score matrix as input
 "factor.score.eigen.start" <- function(A, factors){
 
+  A <- (1 - A)^2
   AA <- A
   arow <- matrix(NA, nrow(A), 1)
   acol <- matrix(NA, ncol(A), 1)
@@ -231,7 +234,7 @@
   
   for (i in 1:nrow(A)){
     for (j in 1:ncol(A)){
-      AA[i,j] <- (A[i,j]-arow[i]-acol[j]+matrixmean)/(2)
+      AA[i,j] <- (A[i,j]-arow[i]-acol[j]+matrixmean)/(-2)
     }
   }
   
